@@ -138,7 +138,7 @@ class RootType(object):
             Value.IsoScanGrub, Value.NetBoot)
     IsoScan = (Value.IsoScanFlash, Value.IsoScanGrub)
 
-    RebuildAvailable = (Value.LiveFlash, Value.IsoScanGrub, Value.IsoScanFlash)
+    RebuildAvailable = (Value.LiveFlash, Value.IsoScanFlash)
     Grubable = (Value.HDD, Value.USB_HDD, Value.IsoScanGrub)
 
 
@@ -165,6 +165,11 @@ class VariableClIsoscanPath(ReadonlyVariable):
     def get(self):
         return getValueFromCmdLine("iso-scan/filename", 0) or ""
 
+class VariableClIsoscanBasePath(ReadonlyVariable):
+    """
+    Путь куда монтируется устройство isoscan
+    """
+    value = Dracut.IsoScanPath
 
 class VariableClIsoscanFullpath(ReadonlyVariable):
     """
@@ -174,7 +179,8 @@ class VariableClIsoscanFullpath(ReadonlyVariable):
     def get(self):
         isoscan_path = self.Get('cl_isoscan_path')
         if isoscan_path:
-            return pathJoin(Dracut.IsoScanPath, isoscan_path)
+            isoscan_base_path = self.Get('cl_isoscan_base_path')
+            return pathJoin(isoscan_base_path, isoscan_path)
         return ""
 
 
